{% load i18n sizeformat %}

<div class="detail">
  <dl class="dl-horizontal">
    <dt title="{% trans 'ID' %}">{% trans "Association ID" %}</dt>
    <dd data-display="{{ network_association.id }}">{{network_association.id|default:_("None") }}</dd>
    <dt title="{% trans 'Network Name' %}">{% trans "Network Name" %}</dt>
    <dd data-display="{{ network_association.network_name|default:_('None') }}">{{ network_association.network_name|default:_("None") }}</dd>
    <dt title="{% trans 'Network ID' %}">{% trans "Network ID" %}</dt>
    <dd><a href="{{ network_association.network_url }}">{{ network_association.network_id|default:_("None") }}</a></dd>
  </dl>
</div>
